==> kipi-plugins-trinity-3.5.13.2.tar.xz: kipi-plugins-trinity-3.5.13.2/kipi-plugins/metadataedit/plugin_metadataedit.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2006-10-11
 * Description : a plugin to edit pictures metadata
 *
 * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef PLUGIN_METADATAEDIT_H
#define PLUGIN_METADATAEDIT_H

// LibKIPI includes.

#include <libkipi/plugin.h>

class KActionMenu;

class Plugin_MetadataEdit : public KIPI::Plugin
{
    Q_OBJECT
  TQ_OBJECT

public:

    Plugin_MetadataEdit(TQObject *parent, const char* name, const TQStringList &args);

    virtual KIPI::Category category( KAction* action ) const;
    virtual void setup( TQWidget* );

protected slots:

    void slotEditExif();
    void slotRemoveExif();
    void slotImportExif();

    void slotEditIptc();
    void slotRemoveIptc();
    void slotImportIptc();

    void slotEditComments();
    void slotRemoveComments();

private:

    KActionMenu     *m_actionMetadataEdit;

    KIPI::Interface *m_interface;
};

#endif // PLUGIN_METADATAEDIT_H

==> kipi-plugins-trinity-14.0.13.tar.xz: kipi-plugins-trinity-14.0.13/kipi-plugins/metadataedit/plugin_metadataedit.h <==
/* ============================================================
 *
 * This file is a part of kipi-plugins project
 * http://www.kipi-plugins.org
 *
 * Date        : 2006-10-11
 * Description : a plugin to edit pictures metadata
 *
 * Copyright (C) 2006-2007 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * ============================================================ */

#ifndef PLUGIN_METADATAEDIT_H
#define PLUGIN_METADATAEDIT_H

// LibKIPI includes.

#include <libkipi/plugin.h>

class TDEActionMenu;

class Plugin_MetadataEdit : public KIPI::Plugin
{
    Q_OBJECT
  

public:

    Plugin_MetadataEdit(TQObject *parent, const char* name, const TQStringList &args);

    virtual KIPI::Category category( TDEAction* action ) const;
    virtual void setup( TQWidget* );

protected slots:

    void slotEditExif();
    void slotRemoveExif();
    void slotImportExif();

    void slotEditIptc();
    void slotRemoveIptc();
    void slotImportIptc();

    void slotEditComments();
    void slotRemoveComments();

private:

    TDEActionMenu     *m_actionMetadataEdit;

    KIPI::Interface *m_interface;
};

#endif // PLUGIN_METADATAEDIT_H
